==> haskell-wai-3.2.2-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai
version: 3.2.2
id: wai-3.2.2-IGekWGpw2KnK7G2kv0Q137
key: wai-3.2.2-IGekWGpw2KnK7G2kv0Q137
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: https://github.com/yesodweb/wai
synopsis: Web Application Interface.
description:
    Provides a common protocol for communication between web applications and web servers.
    .
    API docs and the README are available at <http://www.stackage.org/package/wai>.
category: Web
abi: f66d1911df36fe38e73a600112cd75f6
exposed: True
exposed-modules:
    Network.Wai Network.Wai.Internal
import-dirs: /usr/lib/ghc-8.6.3/site-local/wai-3.2.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/wai-3.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/wai-3.2.2
hs-libraries: HSwai-3.2.2-IGekWGpw2KnK7G2kv0Q137
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    http-types-0.12.3-A4iuC4k1TuV2FAdujp7QrL
    network-2.8.0.0-2IPXD2Y68aq74YznYSHES6 text-1.2.3.1
    transformers-0.5.5.0 vault-0.3.1.2-4YnHXxdrk48D2KnMMRt9j6
haddock-interfaces: /usr/share/doc/haskell-wai/html/wai.haddock
haddock-html: /usr/share/doc/haskell-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-3.2.2-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai
version: 3.2.2
id: wai-3.2.2-7UZCsmzPTqFA7VskjtEotY
key: wai-3.2.2-7UZCsmzPTqFA7VskjtEotY
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: https://github.com/yesodweb/wai
synopsis: Web Application Interface.
description:
    Provides a common protocol for communication between web applications and web servers.
    .
    API docs and the README are available at <http://www.stackage.org/package/wai>.
category: Web
abi: b5ab9dc65a1ab9c59306724b1b2c6e5d
exposed: True
exposed-modules:
    Network.Wai Network.Wai.Internal
import-dirs: /usr/lib/ghc-8.6.4/site-local/wai-3.2.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/wai-3.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/wai-3.2.2
hs-libraries: HSwai-3.2.2-7UZCsmzPTqFA7VskjtEotY
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    http-types-0.12.3-7ETbM18iSLZB08qGmmgPmt
    network-2.8.0.0-65TWeU8omLsDYfm0yvOQxG text-1.2.3.1
    transformers-0.5.6.2 vault-0.3.1.2-3mWiTKQJgRW12cmmatOcbu
haddock-interfaces: /usr/share/doc/haskell-wai/html/wai.haddock
haddock-html: /usr/share/doc/haskell-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
